@@ -109,14 +109,14 @@ $$ LANGUAGE SQL IMMUTABLE PARALLEL SAFE;
 CREATE OR REPLACE FUNCTION path_includes(IN path text[], IN includes text[]) RETURNS BOOLEAN AS $$
 WITH t AS (SELECT unnest(includes) i)
 SELECT EXISTS (
-    SELECT 1 FROM t WHERE path @> string_to_array(i, '.')
+    SELECT 1 FROM t WHERE path @> string_to_array(trim(i), '.')
 );
 $$ LANGUAGE SQL IMMUTABLE PARALLEL SAFE;
 
 CREATE OR REPLACE FUNCTION path_excludes(IN path text[], IN excludes text[]) RETURNS BOOLEAN AS $$
 WITH t AS (SELECT unnest(excludes) e)
 SELECT NOT EXISTS (
-    SELECT 1 FROM t WHERE path @> string_to_array(e, '.')
+    SELECT 1 FROM t WHERE path @> string_to_array(trim(e), '.')
 );
 $$ LANGUAGE SQL IMMUTABLE PARALLEL SAFE;
 
@@ -167,7 +167,6 @@ FOR rec in
 SELECT * FROM jsonb_obj_paths_filtered(jdata, includes, excludes)
 WHERE jsonb_typeof(value) != 'object'
 LOOP
-  RAISE NOTICE 'path % val %', rec.path, rec.value;
     IF array_length(rec.path,1)>1 THEN
         FOR i IN 1..(array_length(rec.path,1)-1) LOOP
           IF NOT array_to_string(rec.path[1:i],'.') = ANY (created_paths) THEN
@@ -756,7 +755,7 @@ SELECT string_agg(rsort,', ') FROM sort_base(_sort);
 $$ LANGUAGE SQL PARALLEL SAFE SET SEARCH_PATH TO pgstac,public;
 
 
-CREATE OR REPLACE FUNCTION bbox_geom(_bbox jsonb) RETURNS box3d AS $$
+CREATE OR REPLACE FUNCTION bbox_geom(_bbox jsonb) RETURNS geometry AS $$
 SELECT CASE jsonb_array_length(_bbox)
     WHEN 4 THEN
         ST_SetSRID(ST_MakeEnvelope(
@@ -799,17 +798,19 @@ op text;
 jp text;
 att_parts RECORD;
 val_str text;
+prop_path text;
 BEGIN
 val_str := lower(jsonb_build_object('a',val)->>'a');
 RAISE NOTICE 'val_str %', val_str;
 
 att_parts := split_stac_path(att);
+prop_path := replace(att_parts.dotpath, 'properties.', '');
 
 op := CASE _op
     WHEN 'eq' THEN '='
     WHEN 'ge' THEN '>='
-    WHEN 'gt' THEN '>'
-    WHEN 'le' THEN '<='
+    WHEN 'gte' THEN '>'
+    WHEN 'lte' THEN '<='
     WHEN 'lt' THEN '<'
     WHEN 'ne' THEN '!='
     WHEN 'neq' THEN '!='
@@ -838,9 +839,9 @@ THEN
     raise notice 'jp: %', jp;
     ret := format($q$ properties @? %L $q$, jp);
 ELSIF jsonb_typeof(val) = 'number' THEN
-    ret := format('(%s)::numeric %s %s', att_parts.jspathtext, op, val);
+    ret := format('properties ? %L AND (%s)::numeric %s %s', prop_path, att_parts.jspathtext, op, val);
 ELSE
-    ret := format('%s %s %L', att_parts.jspathtext, op, val_str);
+    ret := format('properties ? %L AND %s %s %L', prop_path ,att_parts.jspathtext, op, val_str);
 END IF;
 RAISE NOTICE 'Op Query: %', ret;
 
@@ -1036,11 +1037,11 @@ IF _search ? 'token' THEN
         OR
         (not is_prev AND _dtsort = 'ASC')
     THEN
-        _token_dtrange := tstzrange(_token_record.datetime, 'infinity');
+        _token_dtrange := _dtrange * tstzrange(_token_record.datetime, 'infinity');
     ELSIF
         _dtsort IS NOT NULL
     THEN
-        _token_dtrange := tstzrange('-infinity',_token_record.datetime);
+        _token_dtrange := _dtrange * tstzrange('-infinity',_token_record.datetime);
     END IF;
     IF is_prev THEN
         tok_q := filter_by_order(tok_val,  _search->'sortby', 'first');
@@ -1183,4 +1184,4 @@ FROM j
 
 END;
 $$ LANGUAGE PLPGSQL SET SEARCH_PATH TO pgstac,public;
-INSERT INTO migrations (version) ('0.2.3');
+INSERT INTO migrations (version) VALUES ('0.2.5');
