@@ -81,7 +81,7 @@ async def run_migration(dsn: str = None):
         except asyncpg.exceptions.UndefinedTableError:
             oldversion = None
     logging.debug(
-        f"Old Version: {oldversion} Migrations Dir: {migrations_dir}"
+        f"Old Version: {oldversion} New Version: {version} Migrations Dir: {migrations_dir}"
     )
     if oldversion == version:
         logging.debug(f"Target database already at version: {version}")
@@ -139,24 +139,26 @@ class tables(str, Enum):
 async def aiter(list: List):
     for i in list:
         if isinstance(i, bytes):
-            yield i.decode("utf-8").replace("\\n", "\\\\n").replace(
-                "\\t", "\\\\t"
+            i = i.decode("utf-8")
+        elif isinstance(i, dict):
+            i = orjson.dumps(i).decode("utf-8")
+        if isinstance(i, str):
+            line = "\n".join(
+                [
+                    i.rstrip()
+                    .replace(r"\n", r"\\n")
+                    .replace(r"\t", r"\\t")
+                ]
             ).encode("utf-8")
-        elif isinstance(i, str):
-            yield i.replace("\\n", "\\\\n").replace("\\t", "\\\\t").encode(
-                "utf-8"
-            )
+            yield line
         else:
-            yield orjson.dumps(i, option=orjson.OPT_APPEND_NEWLINE).decode(
-                "utf-8"
-            ).replace("\\n", "\\\\n").replace("\\t", "\\\\t").encode("utf-8")
+            raise Exception(f"Could not parse {i}")
 
 
 async def copy(iter, table: tables, conn: asyncpg.Connection):
     logger.debug(f"copying to {table} directly")
-    if isinstance(iter, List):
-        logger.debug("Converting List into Async Iterator")
-        iter = aiter(iter)
+    logger.debug(f"iter: {iter}")
+    iter = aiter(iter)
     async with conn.transaction():
         logger.debug("Copying data")
         await conn.copy_to_table(
@@ -164,7 +166,7 @@ async def copy(iter, table: tables, conn: asyncpg.Connection):
             source=iter,
             columns=["content"],
             format="csv",
-            quote="'",
+            quote=chr(27),
             delimiter=chr(31),
         )
         logger.debug("Backfilling partitions")
@@ -180,9 +182,7 @@ async def copy_ignore_duplicates(
     iter, table: tables, conn: asyncpg.Connection
 ):
     logger.debug(f"inserting to {table} ignoring duplicates")
-    if isinstance(iter, List):
-        logger.debug("Converting List into Async Iterator")
-        iter = aiter(iter)
+    iter = aiter(iter)
     async with conn.transaction():
         await conn.execute(
             """
@@ -195,7 +195,7 @@ async def copy_ignore_duplicates(
             source=iter,
             columns=["content"],
             format="csv",
-            quote="'",
+            quote=chr(27),
             delimiter=chr(31),
         )
         logger.debug("Data Copied")
@@ -220,9 +220,7 @@ async def copy_ignore_duplicates(
 
 async def copy_upsert(iter, table: tables, conn: asyncpg.Connection):
     logger.debug(f"upserting to {table}")
-    if isinstance(iter, List):
-        logger.debug("Converting List into Async Iterator")
-        iter = aiter(iter)
+    iter = aiter(iter)
     async with conn.transaction():
         await conn.execute(
             """
@@ -235,7 +233,7 @@ async def copy_upsert(iter, table: tables, conn: asyncpg.Connection):
             source=iter,
             columns=["content"],
             format="csv",
-            quote="'",
+            quote=chr(27),
             delimiter=chr(31),
         )
         logger.debug("Data Copied")
